@@ -2,7 +2,6 @@ require 'puppet_forge/connection/connection_failure'
 
 require 'faraday'
 require 'faraday_middleware'
-require 'puppet_forge/middleware/symbolify_json'
 
 module PuppetForge
   # Provide a common mixin for adding a HTTP connection to classes.
@@ -43,6 +42,7 @@ module PuppetForge
     end
 
     def self.proxy=(url)
+      url = nil if url.respond_to?(:empty?) && url.empty?
       @proxy = url
     end
 
@@ -50,6 +50,15 @@ module PuppetForge
       @proxy
     end
 
+    def self.accept_language=(lang)
+      lang = nil if lang.respond_to?(:empty?) && lang.empty?
+      @accept_language = lang
+    end
+
+    def self.accept_language
+      @accept_language
+    end
+
     # @param reset_connection [Boolean] flag to create a new connection every time this is called
     # @param opts [Hash] Hash of connection options for Faraday
     # @return [Faraday::Connection] An existing Faraday connection if one was
@@ -57,8 +66,9 @@ module PuppetForge
     def conn(reset_connection = nil, opts = {})
       new_auth = @conn && @conn.headers['Authorization'] != PuppetForge::Connection.authorization
       new_proxy = @conn && ((@conn.proxy.nil? && PuppetForge::Connection.proxy) || (@conn.proxy && @conn.proxy.uri.to_s != PuppetForge::Connection.proxy))
+      new_lang = @conn && @conn.headers['Accept-Language'] != PuppetForge::Connection.accept_language
 
-      if new_auth || new_proxy || reset_connection
+      if reset_connection || new_auth || new_proxy || new_lang
         default_connection(opts)
       else
         @conn ||= default_connection(opts)
@@ -70,7 +80,7 @@ module PuppetForge
 
       begin
         # Use Typhoeus if available.
-        Gem::Specification.find_by_name('typhoeus', '~> 0.6')
+        Gem::Specification.find_by_name('typhoeus', '~> 1.4')
         require 'typhoeus/adapters/faraday'
         adapter = :typhoeus
       rescue Gem::LoadError
@@ -94,13 +104,16 @@ module PuppetForge
         options[:headers][:authorization] = token
       end
 
+      if lang = PuppetForge::Connection.accept_language
+        options[:headers]['Accept-Language'] = lang
+      end
+
       if proxy = PuppetForge::Connection.proxy
         options[:proxy] = proxy
       end
 
       Faraday.new(url, options) do |builder|
-        builder.use PuppetForge::Middleware::SymbolifyJson
-        builder.response(:json, :content_type => /\bjson$/)
+        builder.response(:json, :content_type => /\bjson$/, :parser_options => { :symbolize_names => true })
         builder.response(:raise_error)
         builder.use(:connection_failure)
 
